==> selenium-selenium-4.31.0.gh.tar.gz: selenium-selenium-4.31.0/dotnet/src/webdriver/JavaScriptExceptionThrownEventArgs.cs <==
// <copyright file="JavaScriptExceptionThrownEventArgs.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using System;

namespace OpenQA.Selenium
{
    /// <summary>
    /// Provides data for the JavaScriptExceptionThrown event.
    /// </summary>
    public class JavaScriptExceptionThrownEventArgs : EventArgs
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="JavaScriptExceptionThrownEventArgs"/> type.
        /// </summary>
        /// <param name="message">The message of the exception thrown by JavaScript executing in the browser.</param>
        public JavaScriptExceptionThrownEventArgs(string message)
        {
            Message = message;
        }

        /// <summary>
        /// Gets or sets the message of the exception thrown by JavaScript executing in the browser.
        /// </summary>
        public string Message { get; set; }
    }
}

==> selenium-selenium-4.37.0.gh.tar.gz: selenium-selenium-4.37.0/dotnet/src/webdriver/JavaScriptExceptionThrownEventArgs.cs <==
// <copyright file="JavaScriptExceptionThrownEventArgs.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using System;

namespace OpenQA.Selenium;

/// <summary>
/// Provides data for the JavaScriptExceptionThrown event.
/// </summary>
public class JavaScriptExceptionThrownEventArgs : EventArgs
{
    /// <summary>
    /// Initializes a new instance of the <see cref="JavaScriptExceptionThrownEventArgs"/> type.
    /// </summary>
    /// <param name="message">The message of the exception thrown by JavaScript executing in the browser.</param>
    public JavaScriptExceptionThrownEventArgs(string message)
    {
        Message = message;
    }

    /// <summary>
    /// Gets or sets the message of the exception thrown by JavaScript executing in the browser.
    /// </summary>
    public string Message { get; set; }
}
